import { SKRSContext2D } from "@napi-rs/canvas";
import { Data } from "../structures/Data";
export declare class Util {
    /**
     * Converts the given arg to boolean.
     * @param value - Value to be parsed.
     * @returns {boolean}
     */
    static booleanify(value: string): boolean;
    /**
     * Clones the given argument.
     * @param pairs - Value to be cloned.
     */
    static clone<T>(pairs: T): Map<any, any> | T | T[] | Set<any>;
    /**
     * Fills a canvas text.
     * @param ctx - Canvas context.
     * @param mytext - Text to be filled in the canvas.
     * @param x - X text position.
     * @param y - Y text position.
     * @param width - Textbox width.
     * @param height - Textbox height.
     * @param align - Text align.
     * @param vAlign - Text vertical align.
     */
    static fillText(ctx: SKRSContext2D, mytext: string, x: number, y: number, width: number, height: number, align: string, vAlign: string): void;
    /**
     * Get the height of a canvas text.
     * @param ctx - Canvas context.
     * @param text - Text to be analyzed.
     * @param style - Text style.
     */
    static getTextHeight(ctx: SKRSContext2D, text: string, style: string): number;
    /**
     * Parse a object.
     * @param json - String object to be parsed.
     */
    static loadObject<T>(json: string): T | null;
    /**
     * @param ctx - Canvas context.
     * @param x - X position.
     * @param y - Y position.
     * @param width - Square width.
     * @param height - Square height.
     * @param radius - Square corner radius.
     */
    static molde(ctx: SKRSContext2D, x: number, y: number, width: number, height: number, radius: number): void;
    /**
     * Check whether given arg is number.
     * @param num - String number to be checked.
     * @returns {boolean}
     */
    static isNumber(num: string): boolean;
    /**
     * Check if the given arg is a valid hexadecimal code.
     * @param value - Code to be tested.
     * @returns {boolean}
     */
    static isValidHex(value: string): boolean;
    /**
     * Parses a string-like value.
     * @param text - String to be parsed.
     */
    static parse(text: string): bigint | boolean | null | undefined;
    /**
     * Returns the compilation string from an input code.
     * @param d - Interpreter data.
     * @param code - Code to be resolved.
     * @param returnType - Resolution return type.
     * @returns
     */
    static resolveCode<T>(d: Data, code: string, returnType?: "data" | "code"): Promise<T>;
    /**
     * Converts a integer to decimal fraction.
     * @param value - Number to be converted.
     * @returns {number}
     */
    static resolvePercent(value: number): number;
    /**
     * Returns a string representation of a boolean value.
     * @param value - Value to be converted.
     * @returns {string}
     */
    static stringBool(value: boolean): string;
}
