import { APIFunction, FunctionReturn, ParamType } from "../../structures/APIFunction";
import { Data } from "../../structures/Data";
/**
 * Represents a required JavaScript library.
 */
export interface RequiredPackages {
    /**
     * Library name to be required.
     */
    name: string;
    /**
     * Property to be required from the library.
     * Type "null" represents a CommonJS import.
     */
    property: string | null;
}
export default class AddPackage extends APIFunction {
    name: string;
    description: string;
    parameters: ({
        name: string;
        description: string;
        type: ParamType;
        required: boolean;
        rest: boolean;
        defaultValue: null;
    } | {
        name: string;
        description: string;
        type: ParamType;
        required: boolean;
        rest: boolean;
        defaultValue: string;
    })[];
    usage: string;
    returns: FunctionReturn;
    aliases: string[];
    compile: boolean;
    example: string;
    run(d: Data, [name, property]: string[]): Promise<void>;
}
