import { APIFunction } from "../structures/APIFunction";
export declare class FunctionManager extends Map<string, APIFunction> {
    #private;
    constructor(iterable?: Iterable<readonly [string, APIFunction]> | null | undefined);
    /**
     * Add a function to the manager.
     * @param name - Function name.
     * @param value - Function data.
     */
    add(name: string, value: APIFunction): this;
    /**
     * Injects a subfunction to a supported function.
     * @param target - Target function name.
     * @param name - Subfunction name.
     * @param value - Subfunction value.
     */
    inject(target: string, name: string, value: APIFunction): void;
    /**
     * Return all function available for a supported function.
     * @param target - Target function name.
     */
    getTargettedInjections(target: string): Record<string, APIFunction>;
    /**
     * Load all functions inside a folder.
     * @param dir - Function directory.
     * @param predicate - Predicate to allow loading functions.
     */
    load(dir?: string, predicate?: (fn: APIFunction) => boolean): void;
    /**
     * Returns an array of functions.
     * @returns {APIFunction[]}
     */
    toArray(): APIFunction[];
    /**
     * Return all function injections.
     */
    get injections(): Record<string, Record<string, APIFunction>>;
}
